==> jc-1.4.0.tar.gz: soot/jimple/internal/JXorExpr.h <==
// public class soot.jimple.internal.JXorExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr
// @dep_class 351bd7fa04fc1c8b soot_jimple_internal_JXorExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntLongBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JXorExpr_H_
#define _JC_soot_jimple_internal_JXorExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JXorExpr$sub_refs	_jc_soot_jimple_internal_JXorExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JXorExpr$sub_nonrefs	_jc_soot_jimple_internal_JXorExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JXorExpr$refs	_jc_soot_jimple_internal_JXorExpr$refs;
typedef struct _jc_soot_jimple_internal_JXorExpr$nonrefs	_jc_soot_jimple_internal_JXorExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JXorExpr$object	_jc_soot_jimple_internal_JXorExpr$object;

typedef const struct _jc_soot_jimple_internal_JXorExpr$vmethods	_jc_soot_jimple_internal_JXorExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JXorExpr$vtable	_jc_soot_jimple_internal_JXorExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JXorExpr$vtype	_jc_soot_jimple_internal_JXorExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JXorExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JXorExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JXorExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JXorExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JXorExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JXorExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *);
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JXorExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
	_jc_soot_jimple_internal_JXorExpr$vmethods	soot_jimple_internal_JXorExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JXorExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JXorExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JXorExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JXorExpr$refs {
    _jc_soot_jimple_internal_JXorExpr$sub_refs	soot_jimple_internal_JXorExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JXorExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JXorExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_JXorExpr$sub_nonrefs	soot_jimple_internal_JXorExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JXorExpr$object {
	_jc_soot_jimple_internal_JXorExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JXorExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JXorExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JXorExpr$vtype _jc_soot_jimple_internal_JXorExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JXorExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JXorExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JXorExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JXorExpr.h <==
// public class soot.jimple.internal.JXorExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr
// @dep_class 351bd7fa04fc1c8b soot_jimple_internal_JXorExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntLongBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JXorExpr_H_
#define _JC_soot_jimple_internal_JXorExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JXorExpr$sub_refs	_jc_soot_jimple_internal_JXorExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JXorExpr$sub_nonrefs	_jc_soot_jimple_internal_JXorExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JXorExpr$refs	_jc_soot_jimple_internal_JXorExpr$refs;
typedef struct _jc_soot_jimple_internal_JXorExpr$nonrefs	_jc_soot_jimple_internal_JXorExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JXorExpr$object	_jc_soot_jimple_internal_JXorExpr$object;

typedef const struct _jc_soot_jimple_internal_JXorExpr$vmethods	_jc_soot_jimple_internal_JXorExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JXorExpr$vtable	_jc_soot_jimple_internal_JXorExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JXorExpr$vtype	_jc_soot_jimple_internal_JXorExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JXorExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JXorExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JXorExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JXorExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JXorExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JXorExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JXorExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JXorExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JXorExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
	_jc_soot_jimple_internal_JXorExpr$vmethods	soot_jimple_internal_JXorExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JXorExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JXorExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JXorExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JXorExpr$refs {
    _jc_soot_jimple_internal_JXorExpr$sub_refs	soot_jimple_internal_JXorExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JXorExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JXorExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_JXorExpr$sub_nonrefs	soot_jimple_internal_JXorExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JXorExpr$object {
	_jc_soot_jimple_internal_JXorExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JXorExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JXorExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JXorExpr$vtype _jc_soot_jimple_internal_JXorExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JXorExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JXorExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JXorExpr_H_ */
